==> 0.8.9.tar.gz: lib/widget/vgk-feedback-widget/vgk-feedback-widget.dart <==
import 'package:flutter/material.dart';
import 'package:launch_review/launch_review.dart';
import 'package:share/share.dart';
import 'package:vgkprogaming/theme/vgk-shared-theme.dart';
import 'package:vgkprogaming/widget/vgk-common-widget/vgk-common-widget.dart';

class VgkFeedBackAndShareWidget {
  static Widget vgkFeedBackAndShare(
      String appId, String shareDescription, primaryColor) {
    return Center(
      child: Padding(
        padding: EdgeInsets.all(20),
        child: Row(
          children: <Widget>[
            Expanded(
              child: InkWell(
                onTap: () {
                  LaunchReview.launch(
                    androidAppId: appId,
                  );
                },
                child: VgkCommonWidget.vgkIconWithTextWidget(
                  Icons.feedback,
                  HexColor(primaryColor),
                  "Feedback",
                  VgkProGamingTheme.h3,
                ),
              ),
            ),
            SizedBox(
              width: 10,
            ),
            Expanded(
              child: InkWell(
                onTap: () {
                  Share.share(shareDescription);
                },
                child: VgkCommonWidget.vgkIconWithTextWidget(
                  Icons.share,
                  HexColor(primaryColor),
                  "Share",
                  VgkProGamingTheme.h3,
                ),
              ),
            ),
          ],
        ),
      ),
    );
  }

  static shareApp(shareDescription) {
    Share.share(shareDescription);
  }

  static rateApp(appId) {
    LaunchReview.launch(
      androidAppId: appId,
    );
  }
}

==> 0.9.3.tar.gz: lib/widget/vgk-feedback-widget/vgk-feedback-widget.dart <==
import 'package:flutter/material.dart';
import 'package:launch_review/launch_review.dart';
import 'package:share/share.dart';
import 'package:vgkprogaming/theme/vgk-shared-theme.dart';
import 'package:vgkprogaming/widget/vgk-common-widget/vgk-common-widget.dart';

class VgkFeedBackAndShareWidget {
  static Widget vgkFeedBackAndShare(
      String appId, String shareDescription, primaryColor) {
    return Center(
      child: Padding(
        padding: EdgeInsets.all(20),
        child: Row(
          children: <Widget>[
            Expanded(
              child: InkWell(
                onTap: () {
                  LaunchReview.launch(
                    androidAppId: appId,
                  );
                },
                child: VgkCommonWidget.vgkIconWithTextWidget(
                  Icons.feedback,
                  HexColor(primaryColor),
                  "Feedback",
                  VgkProGamingTheme.h3(primaryColor),
                ),
              ),
            ),
            SizedBox(
              width: 10,
            ),
            Expanded(
              child: InkWell(
                onTap: () {
                  Share.share(shareDescription);
                },
                child: VgkCommonWidget.vgkIconWithTextWidget(
                  Icons.share,
                  HexColor(primaryColor),
                  "Share",
                  VgkProGamingTheme.h3(primaryColor),
                ),
              ),
            ),
          ],
        ),
      ),
    );
  }

  static shareApp(shareDescription) {
    Share.share(shareDescription);
  }

  static rateApp(appId) {
    LaunchReview.launch(
      androidAppId: appId,
    );
  }
}
